Improve this Doc

# Error: $injector:modulerr
Module Error

    Failed to instantiate module {0} due to:
    {1}

## Description

This error occurs when a module fails to load due to some exception. The error message above should provide additional context.

A common reason why the module fails to load is that you've forgotten to include the file with the defined module or that the file couldn't be loaded.

### Using `ngRoute`

In AngularJS `1.2.0` and later, `ngRoute` has been moved to its own module. If you are getting this error after upgrading to `1.2.x` or later, be sure that you've installed `ngRoute`.

### Monkey-patching Angular's `ng` module

This error can also occur if you have tried to add your own components to the `ng` module. This has never been supported and from `1.3.0` it will actually trigger this error. For instance the following code could trigger this error.

    angular.module('ng').filter('tel', function (){});

Instead create your own module and add it as a dependency to your application's top-level module. See #9692 and #7709 for more information